@@ -3,9 +3,9 @@
 # flake8: noqa
 
 """
-    DataCore API  - Sport
+DataCore API  - Sport
 
-    # Introduction
+# Introduction
 
 The DataCore API is a REST based API. This means it makes use of the followng HTTP primitives:
  * GET - To retrieve data
@@ -53,15 +53,11 @@ These URIs can be generated manually by using the `offset` parameter combined wi
 
 
 ## Sorting
-Where allowed, a route can have `sortBy` passed with a list of fields to sort by.  For each allowed field a `-` before the field name will denote DESC sort.  The default (and optional value) as a `+` (ASCENDING).
+Where allowed, a route can have `sortBy` passed with a list of fields to sort by.  For each allowed field a `-` before the field name will denote DESC sort. The default sort is ASCENDING.
 The below example will sort by `startTimeUTC` "descending" then `fixtureNumber` "ascending":
 
 ?sortBy=-startTimeUTC,fixtureNumber
 
-The same can be achieved with:
-
-?sortBy=+fixtureNumber,-startTimeUTC
-
 ## Resource Inclusion
 When a response is returned it will not automatically include extra data from other resources/models. It will only list the resource type and id. eg.
 
@@ -243,14 +239,9 @@ This **access token** must then be sent in the `Authorization` header for each s
 
 <!-- ReDoc-Inject: <security-definitions> -->
   # noqa: E501
-
-    The version of the OpenAPI document: v1
-    Generated by: https://openapi-generator.tech
 """
 
-from __future__ import absolute_import
-
-__version__ = "1.0.1"
+__version__ = "1.4.0"
 
 # import apis into sdk package
 from atriumsports.datacore.openapi.api.awards_api import AwardsApi
@@ -310,6 +301,7 @@ from atriumsports.datacore.openapi.api.video_streams_available_api import VideoS
 
 # import ApiClient
 from atriumsports.datacore.openapi.api_client import ApiClient
+from atriumsports.datacore.openapi.api_response import ApiResponse
 from atriumsports.datacore.openapi.configuration import Configuration
 from atriumsports.datacore.openapi.exceptions import (
     ApiAttributeError,
@@ -327,6 +319,13 @@ from atriumsports.datacore.openapi.models.awards_model import AwardsModel
 from atriumsports.datacore.openapi.models.awards_model_organization import AwardsModelOrganization
 from atriumsports.datacore.openapi.models.awards_response import AwardsResponse
 from atriumsports.datacore.openapi.models.blank_model_response import BlankModelResponse
+from atriumsports.datacore.openapi.models.career_person_season_statistics_model import CareerPersonSeasonStatisticsModel
+from atriumsports.datacore.openapi.models.career_person_season_statistics_model_organization import (
+    CareerPersonSeasonStatisticsModelOrganization,
+)
+from atriumsports.datacore.openapi.models.career_person_season_statistics_response import (
+    CareerPersonSeasonStatisticsResponse,
+)
 from atriumsports.datacore.openapi.models.career_person_statistics_model import CareerPersonStatisticsModel
 from atriumsports.datacore.openapi.models.career_person_statistics_model_organization import (
     CareerPersonStatisticsModelOrganization,
@@ -347,6 +346,9 @@ from atriumsports.datacore.openapi.models.competition_person_statistics_model im
 from atriumsports.datacore.openapi.models.competition_person_statistics_model_organization import (
     CompetitionPersonStatisticsModelOrganization,
 )
+from atriumsports.datacore.openapi.models.competition_person_statistics_response import (
+    CompetitionPersonStatisticsResponse,
+)
 from atriumsports.datacore.openapi.models.competition_post_body import CompetitionPostBody
 from atriumsports.datacore.openapi.models.competition_put_body import CompetitionPutBody
 from atriumsports.datacore.openapi.models.competitions_model import CompetitionsModel
@@ -483,6 +485,8 @@ from atriumsports.datacore.openapi.models.fixture_roster_model_organization impo
 from atriumsports.datacore.openapi.models.fixture_roster_post_body import FixtureRosterPostBody
 from atriumsports.datacore.openapi.models.fixture_roster_response import FixtureRosterResponse
 from atriumsports.datacore.openapi.models.fixture_videosteam_post_body import FixtureVideosteamPostBody
+from atriumsports.datacore.openapi.models.fixtures_by_competition_model import FixturesByCompetitionModel
+from atriumsports.datacore.openapi.models.fixtures_by_competition_response import FixturesByCompetitionResponse
 from atriumsports.datacore.openapi.models.fixtures_by_entity_model import FixturesByEntityModel
 from atriumsports.datacore.openapi.models.fixtures_by_entity_response import FixturesByEntityResponse
 from atriumsports.datacore.openapi.models.fixtures_model import FixturesModel
@@ -679,6 +683,7 @@ from atriumsports.datacore.openapi.models.seasonentity_placings_post_body import
 from atriumsports.datacore.openapi.models.seasonentity_placings_put_body import SEASONENTITYPlacingsPutBody
 from atriumsports.datacore.openapi.models.seasonperson_placings_post_body import SEASONPERSONPlacingsPostBody
 from atriumsports.datacore.openapi.models.seasonperson_placings_put_body import SEASONPERSONPlacingsPutBody
+from atriumsports.datacore.openapi.models.seasonroster_configuration import SEASONROSTERConfiguration
 from atriumsports.datacore.openapi.models.seasons_model import SeasonsModel
 from atriumsports.datacore.openapi.models.seasons_model_competition import SeasonsModelCompetition
 from atriumsports.datacore.openapi.models.seasons_model_fixture_profile import SeasonsModelFixtureProfile
